<a id="packages.valory.skills.safe_deployment_abci.models"></a>

# packages.valory.skills.safe`_`deployment`_`abci.models

This module contains the shared state for the safe_deployment_abci skill.

<a id="packages.valory.skills.safe_deployment_abci.models.SharedState"></a>

## SharedState Objects

```python
class SharedState(BaseSharedState)
```

Keep the current shared state of the skill.

<a id="packages.valory.skills.safe_deployment_abci.models.SharedState.__init__"></a>

#### `__`init`__`

```python
def __init__(*args: Any, **kwargs: Any) -> None
```

Initialize the state.

<a id="packages.valory.skills.safe_deployment_abci.models.Params"></a>

## Params Objects

```python
class Params(BaseParams)
```

Parameters.

<a id="packages.valory.skills.safe_deployment_abci.models.Params.__init__"></a>

#### `__`init`__`

```python
def __init__(*args: Any, **kwargs: Any) -> None
```

Initialize the parameters object.

<a id="packages.valory.skills.safe_deployment_abci.models.RandomnessApi"></a>

## RandomnessApi Objects

```python
class RandomnessApi(ApiSpecs)
```

A model for randomness api specifications.

